@@ -82,7 +82,8 @@ def cal_err_mag (I, I_err):
 
 def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
               user_order=None, user_list=None, sky_box=[100, 100],
-              deblend='off', band='R'):
+              deblend='off', band='R', nsigma=2, npixels=5, dilate_size=11,
+              outputfile='properties.dat', eta=0.2):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -207,10 +208,19 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     area=np.square(sc_imag)
     t=1
 
-
-
-
-    imagn = fits.open('fits_images/' + tab_gal['gal'][idg]+'_{}kpc.fz'.format(size_image_phy))
+    path_a = tab_gal['gal'][idg]+'_{}_{}kpc.fz'.format(band, size_image_phy)
+    if band=='R':
+        try:
+            imagn = fits.open('fits_images/' +
+                    tab_gal['gal'][idg]+'_{}kpc.fz'.format(size_image_phy))
+            print (Fore.RED+ '\nThe analysis is performed on {}'.format(
+                   tab_gal['gal'][idg]+'_{}kpc.fz'.format(size_image_phy)))
+        except:
+            imagn = fits.open('fits_images/' + path_a)
+            print (Fore.RED+ '\nThe analysis is performed on {}'.format(path_a))
+    else:
+        imagn = fits.open('fits_images/' + path_a)
+        print (Fore.RED+ '\nThe analysis is performed on {}'.format(path_a))
     imag = imagn[1].data
 
     ##################
@@ -219,7 +229,8 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     print(Fore.BLUE + '\n\nCalculating the image background')
     print('------------------------------------------')
     print ('Masking the sources over the image...')
-    mask_g = make_source_mask(imag, nsigma=2, npixels=5, dilate_size=11)
+    mask_g = make_source_mask(imag,  sigma=nsigma, npixels=npixels,
+                              dilate_size=dilate_size)
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(mask_g, origin='lower')
     plt.savefig('images/fig_'+gal+'_{}kpc_sky_mask.png'.format(size_image_phy),
@@ -326,7 +337,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
 
     start = time.time()
     source_morphs = statmorph.source_morphology(imag,
-                            segm.data, gain=gain, psf=psfg)
+                            segm.data, gain=gain, psf=psfg, eta=eta)
     print('Time: %g s.' % (time.time() - start))
     print (len(source_morphs))
 
@@ -345,10 +356,10 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
 
            morph = source_morphs[gali]
            plot_stat(morph, gal+listl[i], imag, imagm, median_sky_g, area,t, zp,
-                         psfg,psf_g, sc_imag, arc_kpc, size_image_phy)
+                         psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
+                         outputfile=outputfile)
 
-
-           data = ascii.read('properties.dat')
+           data = ascii.read(outputfile)
 
            ind=np.where(data['GAL']==gal+listl[i])[0][0]
            indgal =np.where(tab_gal['gal']==gal)[0][0]
@@ -364,14 +375,15 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                data['Jclass'][ind] = tab_gal['Jclass'][indgal]
            except:
                print ("")
-           ascii.write(data, 'properties.dat', overwrite=True)
+           ascii.write(data, outputfile, overwrite=True)
     else:
        for i, gali in enumerate(user_order):
            morph = source_morphs[gali]
            plot_stat(morph, gal + user_list[i], imag, imagm, median_sky_g, area,
-                     t, zp, psfg,psf_g, sc_imag, arc_kpc, size_image_phy)
+                     t, zp, psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
+                     outputfile=outputfile)
 
-           data = ascii.read('properties.dat')
+           data = ascii.read(outputfile)
 
            ind=np.where(data['GAL']==gal + user_list[i])[0][0]
            indgal =np.where(tab_gal['gal']==gal)[0][0]
@@ -387,7 +399,7 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                data['Jclass'][ind] = tab_gal['Jclass'][indgal]
            except:
                print ("")
-           ascii.write(data, 'properties.dat', overwrite=True)
+           ascii.write(data, outputfile, overwrite=True)
 
     plt.show()
     nuser_list = []
@@ -401,10 +413,11 @@ def phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                           len(user_order)))
 
 def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
-              sc_ima, arc_kpc, size_image_phy, show_plot='yes'):
+              sc_ima, arc_kpc, size_image_phy, show_plot='yes',
+              outputfile='properties.dat'):
 
-    if os.path.exists('properties.dat'):
-        data = ascii.read('properties.dat')
+    if os.path.exists(outputfile):
+        data = ascii.read(outputfile)
     else:
         direcbase = os.path.dirname(os.path.realpath(__file__))
         datat = ascii.read(direcbase + '/properties.dat')
@@ -467,6 +480,8 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
     data['rhalf_c'][ind] =  morph.rhalf_circ
     data['rhalf_e'][ind] = morph.rhalf_ellip
 
+    print (Fore.RED +'\n Petrosian Radius {:.1f}'.format(morph.rpetro_circ))
+
     data['M'][ind] = morph.multimode
     data['I'][ind] = morph.intensity
     data['D'][ind] = morph.deviation
@@ -485,7 +500,7 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
     data['psf_R'][ind] = psf_g
     data['sizep'][ind] = size_image_phy
 
-    ascii.write(data, 'properties.dat', overwrite=True)
+    ascii.write(data, outputfile, overwrite=True)
 
     ny, nx = imag.shape
     y, x = np.mgrid[0:ny, 0:nx]
@@ -584,7 +599,8 @@ def plot_stat(morph, gal, imag, imagm, median_sky_g, area, t, zp, psfg, psf_g,
 def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
                  region='circle', server=None, limtvel=500, xtpos=10, ytpos=20,
                  deltay=10, sky_box=[100, 100], deblend='off', psf=1,
-                 usesimbad='no', band='R', field_size_phy=100):
+                 usesimbad='no', band='R', field_size_phy=100, nsigma=2,
+                 npixels=5, dilate_size=11):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -763,7 +779,8 @@ def ex_phot_mod (gal, tab_gal, conn, size_image_phy=50, snr_g = 2.0, areagal=2,
     print(Fore.BLUE + '\n\nCalculating the image background')
     print('------------------------------------------')
     print ('Masking the sources over the image...')
-    mask_g = make_source_mask(imag, nsigma=2, npixels=5, dilate_size=11)
+    mask_g = make_source_mask(imag,  nsigma=nsigma, npixels=npixels,
+                              dilate_size=dilate_size)
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(mask_g, origin='lower')
     plt.show()
@@ -1215,7 +1232,7 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
         print(AM['desc','codes'][np.where(AM['gal']==gal)[0]])
 
     if add_object:
-        data = ascii.read('properties.dat')
+        data = ascii.read(outputfile)
 
 
         skyc=SkyCoord(table['RA_d'][user_order], table['DEC_d'][user_order])
@@ -1276,7 +1293,7 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
                 data['D_to_main'][ind] = sep_kpc[i-1]
 
 
-        ascii.write(data, 'properties.dat', overwrite=True)
+        ascii.write(data, outputfile, overwrite=True)
 
 
     import matplotlib as mpl
@@ -1484,7 +1501,8 @@ def plot_simbad(gal, tab_gal, conn, size_image_phy, table, user_order=None,
 
 def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
                         areagal=2, band='r', sky_box=[100, 100], deblend='off',
-                        psf=1, run_auto='no', show_plot='yes'):
+                        psf=1, run_auto='no', show_plot='yes',
+                        nsigma=2, npixels=5, dilate_size=11):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -1568,7 +1586,8 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
     print(Fore.BLUE + '\n\nCalculating the image background')
     print('------------------------------------------')
     print ('Masking the sources over the image...')
-    mask_g = make_source_mask(imag, nsigma=2, npixels=5, dilate_size=11)
+    mask_g = make_source_mask(imag, nsigma=nsigma, npixels=npixels,
+                              dilate_size=dilate_size)
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(mask_g, origin='lower')
     if show_plot=='yes':
@@ -1708,7 +1727,8 @@ def ex_phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0,
 def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
                      band = 'r',
                      user_order=None, user_list=None, sky_box=[100, 100],
-                     deblend='off', show_plot='yes'):
+                     deblend='off', show_plot='yes',nsigma=2, npixels=5,
+                     dilate_size=11, outputfile='properties.dat', eta=0.2):
 
     idg =np.where(tab_gal['gal']==gal)[0][0]
     D = tab_gal['vel'][idg]/H
@@ -1754,7 +1774,8 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
     print(Fore.BLUE + '\n\nCalculating the image background')
     print('------------------------------------------')
     print ('Masking the sources over the image...')
-    mask_g = make_source_mask(imag, nsigma=2, npixels=5, dilate_size=11)
+    mask_g = make_source_mask(imag, nsigma=nsigma, npixels=npixels,
+                              dilate_size=dilate_size)
     fig=plt.figure(figsize=(6.5,6.5))
     plt.imshow(mask_g, origin='lower')
     plt.savefig('images/fig_'+gal+'{}_{}kpc_sky_mask.png'.format(band,
@@ -1874,7 +1895,7 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
 
     start = time.time()
     source_morphs = statmorph.source_morphology(imag,
-                            segm.data, gain=gain, psf=psfg)
+                            segm.data, gain=gain, psf=psfg, eta=eta)
     print('Time: %g s.' % (time.time() - start))
     print (len(source_morphs))
 
@@ -1890,9 +1911,9 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
            morph = source_morphs[gali]
            plot_stat(morph, gal+listl[i], imag, imagm, median_sky_g, area,t, zp,
                          psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
-                         show_plot=show_plot)
+                         show_plot=show_plot, outputfile=outputfile)
 
-           data = ascii.read('properties.dat')
+           data = ascii.read(outputfile)
 
            ind=np.where(data['GAL']==gal+listl[i])[0][0]
            indgal =np.where(tab_gal['gal']==gal)[0][0]
@@ -1903,15 +1924,15 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
            data['z'][ind] = tab_gal['Z'][indgal]
            data['Jclass'][ind] = tab_gal['Jclass'][indgal]
 
-           ascii.write(data, 'properties.dat', overwrite=True)
+           ascii.write(data, outputfile, overwrite=True)
     else:
        for i, gali in enumerate(user_order):
            morph = source_morphs[gali]
            plot_stat(morph, gal + user_list[i], imag, imagm, median_sky_g, area,
                      t, zp, psfg,psf_g, sc_imag, arc_kpc, size_image_phy,
-                     show_plot=show_plot)
+                     show_plot=show_plot, outputfile=outputfile)
 
-           data = ascii.read('properties.dat')
+           data = ascii.read(outputfile)
 
            ind=np.where(data['GAL']==gal + user_list[i])[0][0]
            indgal =np.where(tab_gal['gal']==gal)[0][0]
@@ -1922,7 +1943,7 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
            data['z'][ind] = tab_gal['Z'][indgal]
            data['Jclass'][ind] = tab_gal['Jclass'][indgal]
 
-           ascii.write(data, 'properties.dat', overwrite=True)
+           ascii.write(data, outputfile, overwrite=True)
 
     plt.show()
 
@@ -1992,7 +2013,7 @@ def mass_decals(gal, tab_gal, size_image_phy):
                       size_image_phy))
     imar = imarn[0].data
 
-    data = ascii.read('properties.dat')
+    data = ascii.read(outputfile)
 
     ind=np.where(data['GAL']==gal)[0][0]
 
@@ -2041,7 +2062,7 @@ def mass_decals(gal, tab_gal, size_image_phy):
     Lg = 10**((1.0/2.5)*(5.11-Mg))
     mass_stellar = Lg*MLg
 
-    data = ascii.read('properties.dat')
+    data = ascii.read(outputfile)
 
     ind=np.where(data['GAL']==gal)[0][0]
 
@@ -2059,4 +2080,4 @@ def mass_decals(gal, tab_gal, size_image_phy):
     print(Fore.BLUE +'D_proj = {:.1f} kpc'.format(sep_kpc))
     print(Fore.BLUE +'D_intr = {:.1f} kpc'.format(D_int))
 
-    ascii.write(data, 'properties.dat', overwrite=True)
+    ascii.write(data, outputfile, overwrite=True)
